<?php

/**
 	* Print HTML with meta information for the current post-date/time and author.
 	*
 	* @since Aesop 1.0
	*
	* @return void
*/
if ( ! function_exists( 'genji_posted_on' ) ) :

	function genji_posted_on() {

		// Set up and print post meta information.
		printf( '<p class="genji-entry-date"><a href="%1$s" rel="bookmark"><time datetime="%2$s">%3$s</time></a></span> &middot; <span class="byline"><span class="author vcard"><a class="url fn n" href="%4$s" rel="author">%5$s</a></span></p>',
			esc_url( get_permalink() ),
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			get_the_author()
		);
	}
endif;

if (!function_exists('genji_get_pagination')){
	function genji_get_pagination(){

		global $wp_query, $numpages;

		if ($wp_query->max_num_pages > 1) {

			?><div class="genji-pagination"><?php

				$big = 999999999; // need an unlikely integer

				echo paginate_links( array(
					'base' 		=> str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
					'format' 	=> '?paged=%#%',
					'current' 	=> max( 1, get_query_var('paged') ),
					'total' 	=> $wp_query->max_num_pages
				) );

			?></div><?php
		}
	}
}

/**
  	* Show the post author with links to posts, along with any bio and web stuff set in user meta
  	*
  	*
  	* @author  Nick Haskins <email@nickhaskins.com>
  	* @since 1.0
  	*
*/
if (!function_exists('genji_post_author')):

	function genji_post_author($extended = '', $avatarsize = 40, $link = false, $clean = false, $postedby = ''){


        ob_start();
            the_author_meta('url');
        $author_out_link = ob_get_clean();

        $default_avatar = false;
        $author_email = get_the_author_meta('email');
        $author_name = get_the_author();
        $author_url = get_author_posts_url(  get_the_author_meta( 'ID' ));
        $author_first = get_the_author_meta('first_name');
        $author_desc = get_the_author_meta('description');
        $google_profile = get_the_author_meta( 'google_profile' );

        $author = (true == $link) ? sprintf('<h6 class="media-heading"><a class="genji-fader" href="%s"><small class="genji-author-note">Story by</small> %s</a></h6>', $author_url, $author_name) : sprintf('<h6 class="media-heading"><small class="genji-author-note">Story by</small>%s</h6>', $author_name);

        if (true == $clean) { ?>

            <a class="thumbnail" href="<?php echo $author_out_link; ?>" target="_blank"><?php echo get_avatar( $author_email, $avatarsize, $default_avatar); ?></a>

        	<?php if (true == $extended) { ?>

    
        		<?php echo $author;?>
        		<p class="genji-author-details"><?php echo $author_desc; ?></p>
            	<?php if( $author_out_link != '' ) {
                	printf( '<a href="%s" class="btn btn-default genji-author-link" target="_blank">More of %s  &nbsp;&rsaquo;</a> ', $author_out_link, $author_first);
            	}

            } else { ?>
                <?php echo $author;
            }

        } else { ?>
	        <div class="media genji-post-author">
	            <div class="pull-left">
	                <a class="thumbnail" href="<?php echo $author_out_link; ?>" target="_blank">
	                    <?php echo get_avatar( $author_email, $avatarsize, $default_avatar); ?>
	                </a>
	            </div>
	            <div class="media-body">
	            	<?php if (true == $extended) { ?>
		            	<div class="row">
		            		<div class="col-md-8 genji-author-details-wrap">
		                		<?php echo $author;?>
		                		<p class="genji-author-details"><?php echo $author_desc; ?></p>
		                	</div>
		                	<div class="col-md-4 genji-author-extended-wrap">
			                	<?php if( $author_out_link != '' ) {
			                    	printf( '<a href="%s" class="btn btn-default genji-author-link" target="_blank">More of %s  &nbsp;&rsaquo;</a> ', $author_out_link, $author_first);
			                	} ?>
			                </div>
		                </div>
	                <?php } else { ?>
		                <?php echo $author;?>
	                <?php }?>
	            </div>
	        </div><?php }
    }

endif;

/**
  	* This provides color automation with a check for 50% brightness
  	*
  	* Pass a hex code and it will then check to see if that color is closer to white or black
  	* Mainly so if the user sets black color it returns something else other than black
  	*
  	* @author  Nick Haskins <email@nickhaskins.com>
  	* @since 1.0
  	* @param $key pass a hex color
  	*
*/
if (!function_exists('genji_color_sync')){
	function genji_color_sync($key = '', $lum = 2){

		//break up the color in its RGB components
		$r = hexdec(substr($key,0,2));
		$g = hexdec(substr($key,2,2));
		$b = hexdec(substr($key,4,2));

		$yiq = (($r*299)+($g*587)+($b*114))/1000;

		if ($yiq >= 128){
		    $out = genji_darken($key, $lum);
		}else{
		    //dark color, use bright font
		    $out = genji_lighten($key, $lum);
		}

		return $out;
	}
}
/**
  	* This provides color automation with a check for 50% brightness
  	*
  	* Pass a hex code and it will then check to see if that color is closer to white or black
  	* Mainly so if the user sets black color it returns something else other than black
  	*
  	* @author  Nick Haskins <email@nickhaskins.com>
  	* @since 1.0
  	* @param $key pass a hex color
  	*
*/
if (!function_exists('genji_lighten')){

	function genji_lighten($key = '',$lum = 2) {

		$col = array(hexdec(substr($key,1,2)),hexdec(substr($key,3,2)),hexdec(substr($key,5,2)));

		$lighten = array(255-(255-$col[0])/$lum,255-(255-$col[1])/$lum,255-(255-$col[2])/$lum);
		$lighten = "#".sprintf("%02X%02X%02X", $lighten[0], $lighten[1], $lighten[2]);

		return $lighten;
	}
}
if (!function_exists('genji_darken')){

	function genji_darken($key = '',$lum = 2) {

		$col = array(hexdec(substr($key,1,2)),hexdec(substr($key,3,2)),hexdec(substr($key,5,2)));

		$darken = array($col[0]/$lum,$col[1]/$lum,$col[2]/$lum);
		$darken = "#".sprintf("%02X%02X%02X", $darken[0], $darken[1], $darken[2]);

		return $darken;
	}
}
if (!function_exists('genji_color_invert')){
	function genji_color_invert( $mode = 'dark', $delta = 5 ){

		if($mode == 'light'){

			if(genji_color_detect() == -2)
				return 2*$delta;
			elseif(genji_color_detect() == -1)
				return 1.5*$delta;
			elseif(genji_color_detect() == 1)
				return -1.7*$delta;
			else
				return $delta;

		}else{
			if(genji_color_detect() == -2)
				return -(2*$delta);
			elseif(genji_color_detect() == -1)
				return -$delta;
			else
				return $delta;
		}
	}
}
if (!function_exists('genji_color_detect')){
	function genji_color_detect(){

		$bgcolor = get_theme_mod('genji_background_color');

		$hex = str_replace('#', '', $bgcolor);

		$r = hexdec(substr($hex,0,2));
		$g = hexdec(substr($hex,2,2));
		$b = hexdec(substr($hex,4,2));

		if($r + $g + $b > 750){

			// Light
		    return 1;

		}elseif($r + $g + $b < 120){

			// Really Dark
			return -2;

		}
		elseif($r + $g + $b < 300){

			// Dark
			return -1;

		}else{

			// Meh
		    return false;

		}
	}
}