<?php

function genji_custom_register($wp_customize){
	if ( ! class_exists( 'Genji_WP_Customize_Textarea_Control' ) ) {
	    class Genji_WP_Customize_Textarea_Control extends WP_Customize_Control {
	    	public $type = 'textarea';

	    	public function render_content() {
	    		?>
	    		<label>
	    			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
	    			<textarea style="width: 100%;" rows="5" <?php $this->link(); ?>><?php echo esc_attr( $this->value() ); ?></textarea>
	    		</label>
	    		<?php
	    	}
	    }
	}
}
add_action( 'customize_register', 'genji_custom_register' );

class genjiCustomizer {

	// add new options to new section
	public static function register($wp_customize){

		// APPEARENCE
		$wp_customize->add_section( 'genji_appearence', array(
			'title' 	=> __( 'Genji', 'genji' ),
			'priority' 	=> 110
		) );

		// Logo
		$wp_customize->add_setting( 'genji_site_logo', array(
			'type'		=> 'theme_mod',
			'transport' => 'postMessage'
		) );
		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'genji_site_logo', array(
			'label' => __( 'Site Logo (optional)', 'genji' ),
			'section' => 'genji_appearence',
			'settings' => 'genji_site_logo',
		) ) );

		// BG Color
		$wp_customize->add_setting( 'genji_background_color', array(
			'type'		=> 'theme_mod',
			'transport' => 'postMessage',
			'default'	=> '#FFFFFF',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'genji_background_color', array(
			'label' 	=> __('Background', 'genji'),
			'section' 	=> 'genji_appearence',
			'settings' 	=> 'genji_background_color'
		) ) );

		// Index Text COlor
		$wp_customize->add_setting( 'genji_text_color', array(
			'type' 		=> 'theme_mod',
			'transport' => 'postMessage',
			'default'	=> '#494949',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'genji_text_color', array(
			'label' 	=> __('Text', 'genji'),
			'section' 	=> 'genji_appearence',
			'settings' 	=> 'genji_text_color'
		) ) );

		// Link COlor
		$wp_customize->add_setting( 'genji_link_color', array(
			'type' 		=> 'theme_mod',
			'transport' => 'postMessage',
			'default'	=> '#428bca',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'genji_link_color', array(
			'label' 	=> __('Link', 'genji'),
			'section' 	=> 'genji_appearence',
			'settings' 	=> 'genji_link_color'
		) ) );

		// Footer Text
		$wp_customize->add_setting( 'genji_footer_text', array(
            'default'    =>  '<a href="http://wordpress.org">Proudly powered by WordPress</a>',
            'type'       => 'theme_mod',
            'transport'  => 'postMessage',
            'sanitize_callback' => self::sanitize_text_field(),
        ) );
        $wp_customize->add_control( new Genji_WP_Customize_Textarea_Control( $wp_customize, 'genji_footer_text', array(
            'label'    	=> __( 'Footer Text', 'flacker' ),
            'section'  	=> 'genji_appearence',
            'settings' 	=> 'genji_footer_text',
        ) ) );

		$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
		$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	}

   	public static function live_preview() {
      	wp_enqueue_script('genji-themecustomizer', GENJI_URL.'/assets/js/theme-customizer.js', array( 'jquery','customize-preview' ),	GENJI_VERSION, true);
   	}

	 public static function header_output() {

	 		$bgcolor = get_theme_mod('genji_background_color');
	 		$linkcolor = get_theme_mod('genji_link_color');

	      	?>
	      	<!--Customizer CSS--> 
	      	<style type="text/css">
	           <?php self::generate_css('body,h2,h3,h4,h5,h6, h1 small, h2 small, h3 small, h4 small, h4 small, h5 small, h6 small,.genji-archive-post time, .genji-archive-post .genji-archive-post-author,.genji-site-footer a,.genji-pagination .page-numbers,.genji-author .genji-author-social a, ol.commentlist li div.comment-metadata a,.aesop-image-component .aesop-image-component-caption,.aesop-parallax-sc-caption-wrap,.aesop-documument-component a,.aesop-documument-component a span, .genji-site-header .genji-site-title a, .aesop-cap-cred,.aesop-image-component-caption,.aesop-img-enlarge,.aesop-document-component,.genji-author a ,.aesop-parallax-sc-caption-wrap,.genji-site-header .genji-menu-toggle', 'color', 'genji_text_color'); ?> 
	           <?php self::generate_css('body,.aesop-parallax-sc-caption-wrap,.genji-author,.genji-story-header', 'background-color', 'genji_background_color'); ?> 
	           <?php self::generate_css('.genji-site-footer a:hover, .genji-pagination .page-numbers:hover,body a:hover,.genji-comments-wrap .genji-comments-toggle:hover,.genji-author .genji-author-social a:hover,.genji-story-header .genji-go-home:hover i,.genji-author a:hover', 'color', 'genji_link_color'); ?>
	           <?php self::generate_css('.genji-entry-top .genji-cat-links a,.genji-entry-tags a,.genji-site-header .genji-menu-toggle:hover,.genji-entry-tags a[href]:hover, .genji-entry-tags a[href]:focus,.genji-entry-top .genji-cat-links a[href]:hover, .genji-entry-top .genji-cat-links a[href]:focus', 'background-color', 'genji_link_color'); ?>

	           <?php if ($bgcolor) { ?>
	           		body .genji-story-header {
	           			background: <?php echo genji_color_sync($bgcolor, 1.1);?>;
	           		}
	           		body .genji-comments-wrap #genji-comments,
	           		body .aesop-documument-component a span,
	           		body .genji-archive-post {
	           			border-bottom: 1px solid <?php echo genji_color_sync($bgcolor, 1.1);?>;
	           		}
	           		body .ol.commentlist li {
	           			border-top: 1px solid <?php echo genji_color_sync($bgcolor, 1.1);?>;
	           		}
	           		body .genji-author,
	           		body .genji-pagination {
	           			border-top: 1px solid <?php echo genji_color_sync($bgcolor, 1.1);?>;
	           			border-bottom: 1px solid <?php echo genji_color_sync($bgcolor, 1.1);?>;
	           		}
	           		body .genji-comments-wrap .genji-comments-toggle,
	           		body .genji-archive-post img {
	           			border: 1px solid <?php echo genji_color_sync($bgcolor, 1.1);?>;
	           		}
	           		body .genji-story-header .genji-go-home {
	           			border-right:1px solid <?php echo $bgcolor;?>;
	           		}
	           		body .aesop-character-component .aesop-character-cap {
	           			border-top:1px dotted <?php echo $linkcolor;?>;
	           		}

	           	<?php } ?>
	      </style>
	      <!--/Customizer CSS-->
	      <?php }

    public static function generate_css( $selector, $style, $mod_name, $prefix='', $postfix='', $echo=true ) {
      $return = '';
      $mod = get_theme_mod($mod_name);
      if ( ! empty( $mod ) ) {
         $return = sprintf('%s { %s:%s; }',
            $selector,
            $style,
            $prefix.$mod.$postfix
         );
         if ( $echo ) {
            echo $return;
         }
      }
      return $return;
    }

	private static function sanitize_text_field( $input = ''  ) {
		return sanitize_text_field( $input );
	}

	private static function sanitize_int( $input = ''  ) {
		return wp_filter_nohtml_kses( round( $input ) );

	}

}
// Setup the Theme Customizer settings and controls...
add_action( 'customize_register' , array( 'genjiCustomizer' , 'register' ) );
add_action( 'wp_head' , array( 'genjiCustomizer' , 'header_output' ) );
add_action( 'customize_preview_init' , array( 'genjiCustomizer' , 'live_preview' ) );


